__version__ = '1.0.0'

import string

DEFAULT_ALPHABET = string.digits + string.ascii_lowercase + string.ascii_uppercase


def short(number: int, alphabet: list=DEFAULT_ALPHABET):
    """ Converts an integer to a hexdigest like string -
        except not 16 length but provided alphabet length """
    if not isinstance(number, int):
        raise TypeError('number must be an integer')
    result = ''
    sign = ''
    if number < 0:
        sign = '-'
        number = -number
    if 0 <= number < len(alphabet):
        return sign + alphabet[number]
    while number != 0:
        number, i = divmod(number, len(alphabet))
        result = alphabet[i] + result
    return result


def expand(string: str, alphabet=DEFAULT_ALPHABET):
    """ Enter hexdigest like string - return integer (base 10) """
    result = 0
    char_list = list(enumerate(string[::-1]))
    for char in char_list:
        result += (alphabet.index(char[1]) * len(alphabet) ** char[0])
    return result



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import sys


try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

if sys.argv[-1] == 'publish':
    os.system('pandoc --from=markdown --to=rst -o README.rst README.md')
    os.system('python setup.py sdist upload')
    sys.exit()

README = open('README.md').read()
HISTORY = open('CHANGES.txt').read().replace('.. :changelog:', '')

setup(
    name='num_shorty',
    version='1.0.0',
    description="Converts an integer to a hexdigest like string - except not 16 length but provided alphabet length",
    long_description=README + '\n\n' + HISTORY,
    author='Matouš Höschl',
    packages=[
        'num_shorty',
    ],
    package_dir={'num_shorty': 'num_shorty'},
    include_package_data=True,
    license='MIT',
    zip_safe=False,
    entry_points={
    },
    download_url='https://github.com/matousgit/num_shorty/archive/1.0.0.tar.gz',
    classifiers=[
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'Programming Language :: Python :: 3.7',
    ],
    test_suite='tests',
)
